var currentDurationDays = 1; // TBD: Move this to session cookie store?

/**
 * Re-render timeline view with the specified date range
 *
 * @param direction   '+' = increase number of days / '-' = decrease number of days
 */
function attachTimelineManipulationHandlers() {
    $("#zoom-in-button").off("click").on("click",function () {
        timelineZoomHandler('+');
    });

    $("#zoom-out-button").off("click").on("click",function () {
        timelineZoomHandler('-');
    });

    $('#fullcalendar_scheduler .fc-header-toolbar .fc-center h2').datetimepicker({
        timepicker: false,
        format: 'Y-m-d',
        onChangeDateTime: function (dp, $input) {
            updateTimelineDuration($input.val());
        },
    });
}

/**
 * Re-render timeline view with the specified date range
 *
 * @param direction   '+' = increase number of days / '-' = decrease number of days
 */
function timelineZoomHandler(direction) {
    switch (direction) {
        case '+':
            currentDurationDays = currentDurationDays * 2;
            break;
        case '-':
            currentDurationDays = currentDurationDays / 2;
            break;
    }

    updateTimelineDuration();
}

/**
 * Re-render timeline view with the specified date range
 *
 * Examples:
 * updateTimelineDuration()
 * - use the date fields from the form
 *
 * updateTimelineDuration('2019-11-21')
 * - use the supplied start_date + the 'currentDurationDays'
 *
 * updateTimelineDuration('2019-11-21','2019-11-29')
 * - override any form values
 *
 * @param start_date Start date
 * @param end_date   End date
 */
function updateTimelineDuration(start_date, end_date) {
    if (typeof start_date === 'undefined' || start_date === null || start_date.length == 0) {
        start_date = $.trim($("#start_date").val()).substring(0, 10);
    }

    if (typeof end_date === 'undefined' || end_date === null || end_date.length == 0) {
        // TODO: Remove this! Determination of the end date should be based on repeating event parameters
        //end_date = $.trim($("#end_date").val()).substring(0, 10);
    }

    if (typeof end_date === 'undefined' || end_date === null || end_date.length == 0) {
        currentDurationDays = 1;
        end_date = dateAdd(start_date, 'day', currentDurationDays - 1);
    }

    var startDate = new Date(start_date);
    var endDate = new Date(end_date);

    currentDurationDays = Math.round((endDate - startDate) / (1000 * 60 * 60 * 24)) + 1;
    if (currentDurationDays < 1) { currentDurationDays = 1; }

    // Adjust timeline
    $('#fullcalendar_scheduler').fullCalendar('changeView', 'timeline', new Date(start_date).yyyymmdd());
    $('#fullcalendar_scheduler').fullCalendar('option', 'visibleRange', {
        start: new Date(start_date).yyyymmdd(),
        end: dateAdd(start_date, 'day', currentDurationDays).yyyymmdd(),
    });
    $('#fullcalendar_scheduler').fullCalendar('render');

    // Update zoom-text
    $('#zoom-text').text(currentDurationDays + ' days');
}
